@@ -1,16 +1,21 @@
-use serde::de::{Deserialize, Deserializer};
-use serde::ser::{Serialize, Serializer};
-use solana_sdk::{
-    account::Account, account::AccountSharedData, instruction::InstructionError, pubkey::Pubkey,
-};
-use solana_vote_program::vote_state::VoteState;
-use std::{
-    borrow::Borrow,
-    cmp::Ordering,
-    collections::{hash_map::Entry, HashMap},
-    iter::FromIterator,
-    ops::Deref,
-    sync::{Arc, Once, RwLock, RwLockReadGuard},
+use {
+    serde::{
+        de::{Deserialize, Deserializer},
+        ser::{Serialize, Serializer},
+    },
+    solana_sdk::{
+        account::{Account, AccountSharedData},
+        instruction::InstructionError,
+        pubkey::Pubkey,
+    },
+    solana_vote_program::vote_state::VoteState,
+    std::{
+        cmp::Ordering,
+        collections::{hash_map::Entry, HashMap},
+        iter::FromIterator,
+        ops::Deref,
+        sync::{Arc, Once, RwLock, RwLockReadGuard},
+    },
 };
 
 // The value here does not matter. It will be overwritten
@@ -28,9 +33,11 @@ pub struct VoteAccount {
     vote_state_once: Once,
 }
 
+pub type VoteAccountsHashMap = HashMap<Pubkey, (/*stake:*/ u64, ArcVoteAccount)>;
+
 #[derive(Debug, AbiExample)]
 pub struct VoteAccounts {
-    vote_accounts: HashMap<Pubkey, (u64 /*stake*/, ArcVoteAccount)>,
+    vote_accounts: VoteAccountsHashMap,
     staked_nodes: RwLock<
         HashMap<
             Pubkey, // VoteAccount.vote_state.node_pubkey.
@@ -41,6 +48,10 @@ pub struct VoteAccounts {
 }
 
 impl VoteAccount {
+    pub fn account(&self) -> &Account {
+        &self.account
+    }
+
     pub fn lamports(&self) -> u64 {
         self.account.lamports
     }
@@ -185,6 +196,12 @@ impl From<Account> for ArcVoteAccount {
     }
 }
 
+impl AsRef<VoteAccount> for ArcVoteAccount {
+    fn as_ref(&self) -> &VoteAccount {
+        &self.0
+    }
+}
+
 impl From<AccountSharedData> for VoteAccount {
     fn from(account: AccountSharedData) -> Self {
         Self {
@@ -258,8 +275,6 @@ impl PartialEq<VoteAccounts> for VoteAccounts {
     }
 }
 
-type VoteAccountsHashMap = HashMap<Pubkey, (u64 /*stake*/, ArcVoteAccount)>;
-
 impl From<VoteAccountsHashMap> for VoteAccounts {
     fn from(vote_accounts: VoteAccountsHashMap) -> Self {
         Self {
@@ -270,8 +285,8 @@ impl From<VoteAccountsHashMap> for VoteAccounts {
     }
 }
 
-impl Borrow<VoteAccountsHashMap> for VoteAccounts {
-    fn borrow(&self) -> &VoteAccountsHashMap {
+impl AsRef<VoteAccountsHashMap> for VoteAccounts {
+    fn as_ref(&self) -> &VoteAccountsHashMap {
         &self.vote_accounts
     }
 }
@@ -306,12 +321,14 @@ impl<'de> Deserialize<'de> for VoteAccounts {
 
 #[cfg(test)]
 mod tests {
-    use super::*;
-    use bincode::Options;
-    use rand::Rng;
-    use solana_sdk::{pubkey::Pubkey, sysvar::clock::Clock};
-    use solana_vote_program::vote_state::{VoteInit, VoteStateVersions};
-    use std::iter::repeat_with;
+    use {
+        super::*,
+        bincode::Options,
+        rand::Rng,
+        solana_sdk::{pubkey::Pubkey, sysvar::clock::Clock},
+        solana_vote_program::vote_state::{VoteInit, VoteStateVersions},
+        std::iter::repeat_with,
+    };
 
     fn new_rand_vote_account<R: Rng>(
         rng: &mut R,
